###################################
Welcome to pyroSAR's documentation!
###################################

General Topics
==============

.. toctree::
   :maxdepth: 1

   general/installation
   general/filenaming
   general/OSV
   general/DEM
   general/snap
   general/processing
   general/logging

API Documentation
=================

.. toctree::

   pyroSAR

About
=====

.. toctree::
   :maxdepth: 1

   about/projects
   about/changelog
   about/publications
   about/references

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
